#Go to apps.twitter.com.  Create a new app and use those credentials for your consumer key and secret
#after you've create a new app, you can generate an access token and secret for your account/app

CONSUMER_KEY='Your Consumer Key'
CONSUMER_SECRET='Your Consumer Secret'

ACCESS_TOKEN='Your access token'
ACCESS_TOKEN_SECRET='Your secret access token'
